@@ -2,7 +2,7 @@ from dataclasses import dataclass
 from . import blockchain, country
 import random
 from dataclasses import asdict
-
+from datetime import datetime
 genders = ["female", "male"]
 
 @dataclass
@@ -11,7 +11,9 @@ class User:
   first_name:       str
   last_name:        str
   full_name:        str
+  birthday:         datetime
   age:              int
+  anual_income:     int = 0
   username:         str = None
   password:         str = None
   gender:           str = None
